@@ -75,7 +75,7 @@ func (s *RealSystem) RunCmd(cmd *exec.Cmd) error {
 }
 
 // RunScript implements System.RunScript.
-func (s *RealSystem) RunScript(scriptname RelPath, dir AbsPath, data []byte) (err error) {
+func (s *RealSystem) RunScript(scriptname RelPath, dir AbsPath, data []byte, interpreter *Interpreter) (err error) {
 	// Write the temporary script file. Put the randomness at the front of the
 	// filename to preserve any file extension for Windows scripts.
 	f, err := os.CreateTemp("", "*."+scriptname.Base())
@@ -99,42 +99,16 @@ func (s *RealSystem) RunScript(scriptname RelPath, dir AbsPath, data []byte) (er
 		return
 	}
 
-	//nolint:gosec
-	cmd := exec.Command(f.Name())
+	cmd := interpreter.ExecCommand(f.Name())
+	cmd.Dir, err = s.getScriptWorkingDir(dir)
+	if err != nil {
+		return err
+	}
 	cmd.Stdin = os.Stdin
 	cmd.Stdout = os.Stdout
 	cmd.Stderr = os.Stderr
 
-	// Determine the script's working directory.
-	//
-	// If this is a before_ script then the requested working directory may not
-	// actually exist yet, so search through the parent directory hierarchy till
-	// we find a suitable working directory.
-	//
-	// This should always terminate because dir will eventually become ".", i.e.
-	// the current directory.
-FOR:
-	for {
-		switch info, err := s.Stat(dir); {
-		case err == nil && info.IsDir():
-			// dir exists and is a directory. Use it.
-			dirRawAbsPath, err := s.RawPath(dir)
-			if err != nil {
-				return err
-			}
-			cmd.Dir = string(dirRawAbsPath)
-			break FOR
-		case err == nil || errors.Is(err, fs.ErrNotExist):
-			// Either dir does not exist, or it exists and is not a directory.
-			dir = dir.Dir()
-		default:
-			// Some other error occurred.
-			return err
-		}
-	}
-
-	err = s.RunCmd(cmd)
-	return
+	return s.RunCmd(cmd)
 }
 
 // Stat implements System.Stat.
@@ -146,3 +120,30 @@ func (s *RealSystem) Stat(name AbsPath) (fs.FileInfo, error) {
 func (s *RealSystem) UnderlyingFS() vfs.FS {
 	return s.fileSystem
 }
+
+// getScriptWorkingDir returns the script's working directory.
+//
+// If this is a before_ script then the requested working directory may not
+// actually exist yet, so search through the parent directory hierarchy till
+// we find a suitable working directory.
+func (s *RealSystem) getScriptWorkingDir(dir AbsPath) (string, error) {
+	// This should always terminate because dir will eventually become ".", i.e.
+	// the current directory.
+	for {
+		switch info, err := s.Stat(dir); {
+		case err == nil && info.IsDir():
+			// dir exists and is a directory. Use it.
+			dirRawAbsPath, err := s.RawPath(dir)
+			if err != nil {
+				return "", err
+			}
+			return string(dirRawAbsPath), nil
+		case err == nil || errors.Is(err, fs.ErrNotExist):
+			// Either dir does not exist, or it exists and is not a directory.
+			dir = dir.Dir()
+		default:
+			// Some other error occurred.
+			return "", err
+		}
+	}
+}
